@@ -18,11 +18,10 @@ class cBaumWelchInParam : public cInParam
 		double		mTol			; // Tolrance Algor cBaumWelch
 		uint		mNInitIter		; // Nbre d'itrations pour l'initialisation
 		uint		mNMaxIterInit	; // Nbre d'iter max dans la procdure d'initialisation
-		bool		mNoHmm			; // Vrai si on n'a qu'un mlange et pas de HMM
 		uint		mVerbose		; /* 0 rien, 1 imprime */
 	public :
 		cBaumWelchInParam & operator =(const cBaumWelchInParam &theSrc) ;
-		cBaumWelchInParam(uint theNSample=0, uint theDimObs=0, cOTVector *theY=NULL, distrDefinitionEnum theDistrType=eNormalDistr, uint theNClass=2, uint theNMixt=0, uint theNProba=0, bool theNoHMM=false) ;
+		cBaumWelchInParam(uint theNSample=0, uint theDimObs=0, cOTVector *theY=NULL, distrDefinitionEnum theDistrType=eNormalDistr, uint theNClass=2, uint theNMixt=0, uint theNProba=0) ;
 		void SetDefault(void) ;
 		virtual ~cBaumWelchInParam() ;
 		void Print(void) ;
